@@ -16,7 +16,7 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
-from tonicdnscli.__init__ import __timeout__
+from . import __timeout__
 
 
 def tonicDNSClient(uri, method, token='', data='', keyword='', domain=''):
@@ -167,6 +167,7 @@ def formattedPrint(datas):
               % ('name', 'type', 'notified_serial'))
         hr()
         for record in datas:
+
             # print 'NAME'
             utils.print_inline("%(name)-20s" % record)
 
@@ -175,13 +176,15 @@ def formattedPrint(datas):
 
             if record.get('notified_serial'):
                 print("%(notified_serial)s" % record)
+            else:
+                print('')
 
         exit(0)
 
     elif datas.get('records'):
         print("domain: %(name)s" % datas)
 
-        if datas.get('type') == 'MASTER':
+        if datas.get('type') == 'MASTER' and datas.get('notified_serial'):
             print("serial: %(notified_serial)s" % datas)
 
         print("DNS   : %(type)s" % datas)
