@@ -16,7 +16,7 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
-import tonicdnscli.connect as conn
+from . import connect as conn
 
 
 def unprovide():
